@@ -236,10 +236,10 @@ class TC_View < Test::Unit::TestCase
   def test_to_html_digest()
     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"]
     array2 = ["c", "d", "X", "\n", "Y", "e", "\n", "F", "\n"]
-    expected =   ["<ul><hr />",
-                  "<li class=\"entry\"><p class=\"position\">1-2,(1)</p><blockquote class=\"body\"><p class=\"body\"><span class=\"del\"><del>a<br />\nb</del></span>cd</p></blockquote></li><hr />\n",
-                  "<li class=\"entry\"><p class=\"position\">(2),1-2</p><blockquote class=\"body\"><p class=\"body\">cd<span class=\"add\"><ins>X<br />\nY</ins></span>e<br />\n</p></blockquote></li><hr />\n",
-                  "<li class=\"entry\"><p class=\"position\">3,3</p><blockquote class=\"body\"><p class=\"body\">e<br />\n<span class=\"before_change\"><del>f</del></span><span class=\"after_change\"><ins>F</ins></span><br />\n</p></blockquote></li><hr />\n",
+    expected =   ["<ul>",
+                  "<li class=\"entry\"><p class=\"position\">1-2,(1)</p><blockquote class=\"body\"><p class=\"body\"><span class=\"del\"><del>a<br />\nb</del></span>cd</p></blockquote></li>\n",
+                  "<li class=\"entry\"><p class=\"position\">(2),1-2</p><blockquote class=\"body\"><p class=\"body\">cd<span class=\"add\"><ins>X<br />\nY</ins></span>e<br />\n</p></blockquote></li>\n",
+                  "<li class=\"entry\"><p class=\"position\">3,3</p><blockquote class=\"body\"><p class=\"body\">e<br />\n<span class=\"before-change\"><del>f</del></span><span class=\"after-change\"><ins>F</ins></span><br />\n</p></blockquote></li>\n",
                   "</ul>"]
     assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_html_digest(nil,false))
   end
@@ -259,7 +259,7 @@ class TC_View < Test::Unit::TestCase
     array2 = ['a', 'x', 'c']
     difference = Difference.new(array1, array2)
     expected =   ['<span class="common">a</span>',
-                  '<span class="before_change"><del>b</del></span><span class="after_change"><ins>x</ins></span>',
+                  '<span class="before-change"><del>b</del></span><span class="after-change"><ins>x</ins></span>',
                   '<span class="common">c</span>']
     assert_equal(expected, View.new(difference, "ASCII", nil).to_html(nil, false))
   end
@@ -284,7 +284,7 @@ class TC_View < Test::Unit::TestCase
     array1 = ['', '', '']
     array2 = ['', '', '']
     expected =   ['<span class="common"></span>',
-                  '<span class="before_change"><del></del></span><span class="after_change"><ins></ins></span>',
+                  '<span class="before-change"><del></del></span><span class="after-change"><ins></ins></span>',
                   '<span class="common"></span>']
     assert_equal(expected, View.new(Difference.new(array1, array2), "EUC-JP", nil).to_html(nil, false))
     assert_equal(expected.collect{|i|NKF.nkf("-s",i)},
@@ -486,6 +486,27 @@ class TC_View < Test::Unit::TestCase
     assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").to_user_digest(user_tags, false))
   end
 
+  def test_difference_whole()
+    array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"] # a \n  b  c  d           e \n  f \n
+    array2 = ["c", "d", "X", "\n", "Y", "e", "\n", "F", "\n"] #          c  d  X \n  Y  e \n  F \n
+    expected = [[:del_elt, ["a", "\n", "b"], nil],
+                [:common_elt_elt, ["c", "d"], ["c", "d"]],
+                [:add_elt, nil, ["X", "\n", "Y"]],
+                [:common_elt_elt, ["e", "\n"], ["e", "\n"]],
+                [:change_elt, ["f"], ["F"]],
+                [:common_elt_elt, ["\n"], ["\n"]]]
+    assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").difference_whole)
+  end
+
+#   def test_difference_digest()
+#     array1 = ["a", "\n", "b", "c", "d", "e", "\n", "f", "\n"] # a \n  b  c  d           e \n  f \n
+#     array2 = ["c", "d", "X", "\n", "Y", "e", "\n", "F", "\n"] #          c  d  X \n  Y  e \n  F \n
+#     expected = [
+# # something
+#                ]
+#     assert_equal(expected, View.new(Difference.new(array1, array2), "ASCII", "LF").difference_digest)
+#   end
+
   def teardown()
     #
   end
